@@ -91,7 +91,7 @@ class required(BaseValidation):
         Returns:
             bool
         """
-        return attribute
+        return attribute or key in dictionary
 
     def message(self, key):
         """A message to show when this rule fails
@@ -353,7 +353,15 @@ class active_domain(BaseValidation):
 
 class numeric(BaseValidation):
     def passes(self, attribute, key, dictionary):
-        return str(attribute).isdigit()
+        print("str", str(attribute))
+        if isinstance(attribute, list):
+            for value in attribute:
+                if not str(value).isdigit():
+                    return False
+        else:
+            return str(attribute).isdigit()
+
+        return True
 
     def message(self, attribute):
         return "The {} must be a numeric.".format(attribute)
@@ -385,7 +393,7 @@ class none(BaseValidation):
 
 
 class length(BaseValidation):
-    def __init__(self, validations, min=1, max=999999, messages={}, raises={}):
+    def __init__(self, validations, min=1, max=False, messages={}, raises={}):
         super().__init__(validations, messages=messages, raises=raises)
         if isinstance(min, str) and ".." in min:
             self.min = int(min.split("..")[0])
@@ -398,14 +406,20 @@ class length(BaseValidation):
         return len(str(attribute)) >= self.min and len(str(attribute)) <= self.max
 
     def message(self, attribute):
-        return "The {} length must be between {} and {}.".format(
-            attribute, self.min, self.max
-        )
+        if self.min and not self.max:
+            return "The {} must be at least {} characters.".format(attribute, self.min)
+        else:
+            return "The {} length must be between {} and {}.".format(
+                attribute, self.min, self.max
+            )
 
     def negated_message(self, attribute):
-        return "The {} length must not be between {} and {}.".format(
-            attribute, self.min, self.max
-        )
+        if self.min and not self.max:
+            return "The {} must be {} characters maximum.".format(attribute, self.max)
+        else:
+            return "The {} length must not be between {} and {}.".format(
+                attribute, self.min, self.max
+            )
 
 
 class in_range(BaseValidation):
@@ -739,6 +753,21 @@ class confirmed(BaseValidation):
         return "The {} confirmation matches.".format(attribute)
 
 
+class regex(BaseValidation):
+    def __init__(self, validations, pattern, messages={}, raises={}):
+        super().__init__(validations, messages=messages, raises=raises)
+        self.pattern = pattern
+
+    def passes(self, attribute, key, dictionary):
+        return re.compile(r"{}".format(self.pattern)).match(attribute)
+
+    def message(self, attribute):
+        return "The {} does not match pattern {} .".format(attribute, self.pattern)
+
+    def negated_message(self, attribute):
+        return "The {} matches pattern {} .".format(attribute, self.pattern)
+
+
 def flatten(iterable):
 
     flat_list = []
